# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-trading-helper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import mrpc_mt5_error_pb2 as mrpc__mt5__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!mt5-term-api-trading-helper.proto\x12\x0cmt5_term_api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14mrpc-mt5-error.proto\"E\n\x11OrderCloseRequest\x12\x0e\n\x06ticket\x18\x01 \x01(\x04\x12\x0e\n\x06volume\x18\x02 \x01(\x01\x12\x10\n\x08slippage\x18\x05 \x01(\x05\"q\n\x0fOrderCloseReply\x12,\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.mt5_term_api.OrderCloseDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xa1\x01\n\x0eOrderCloseData\x12\x15\n\rreturned_code\x18\x01 \x01(\r\x12\x1c\n\x14returned_string_code\x18\x02 \x01(\t\x12!\n\x19returned_code_description\x18\x03 \x01(\t\x12\x37\n\nclose_mode\x18\x04 \x01(\x0e\x32#.mt5_term_api.MRPC_ORDER_CLOSE_MODE\"\xed\x02\n\x12OrderModifyRequest\x12\x0e\n\x06ticket\x18\x01 \x01(\x04\x12\x16\n\tstop_loss\x18\x02 \x01(\x01H\x00\x88\x01\x01\x12\x18\n\x0btake_profit\x18\x03 \x01(\x01H\x01\x88\x01\x01\x12\x12\n\x05price\x18\x04 \x01(\x01H\x02\x88\x01\x01\x12J\n\x14\x65xpiration_time_type\x18\x05 \x01(\x0e\x32\'.mt5_term_api.TMT5_ENUM_ORDER_TYPE_TIMEH\x03\x88\x01\x01\x12\x38\n\x0f\x65xpiration_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04\x88\x01\x01\x12\x17\n\nstop_limit\x18\x08 \x01(\x01H\x05\x88\x01\x01\x42\x0c\n\n_stop_lossB\x0e\n\x0c_take_profitB\x08\n\x06_priceB\x17\n\x15_expiration_time_typeB\x12\n\x10_expiration_timeB\r\n\x0b_stop_limit\"s\n\x10OrderModifyReply\x12-\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1d.mt5_term_api.OrderModifyDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xff\x01\n\x0fOrderModifyData\x12\x15\n\rreturned_code\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x65\x61l\x18\x02 \x01(\x04\x12\r\n\x05order\x18\x03 \x01(\x04\x12\x0e\n\x06volume\x18\x04 \x01(\x01\x12\r\n\x05price\x18\x05 \x01(\x01\x12\x0b\n\x03\x62id\x18\x06 \x01(\x01\x12\x0b\n\x03\x61sk\x18\x07 \x01(\x01\x12\x0f\n\x07\x63omment\x18\x08 \x01(\t\x12\x12\n\nrequest_id\x18\t \x01(\r\x12\x19\n\x11ret_code_external\x18\n \x01(\x05\x12\x1c\n\x14returned_string_code\x18\x0b \x01(\t\x12!\n\x19returned_code_description\x18\x0c \x01(\t\"\xaa\x04\n\x10OrderSendRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x35\n\toperation\x18\x02 \x01(\x0e\x32\".mt5_term_api.TMT5_ENUM_ORDER_TYPE\x12\x0e\n\x06volume\x18\x03 \x01(\x01\x12\x12\n\x05price\x18\x04 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08slippage\x18\x05 \x01(\x04H\x01\x88\x01\x01\x12\x16\n\tstop_loss\x18\x06 \x01(\x01H\x02\x88\x01\x01\x12\x18\n\x0btake_profit\x18\x07 \x01(\x01H\x03\x88\x01\x01\x12\x14\n\x07\x63omment\x18\x08 \x01(\tH\x04\x88\x01\x01\x12\x16\n\texpert_id\x18\t \x01(\x04H\x05\x88\x01\x01\x12\x1d\n\x10stop_limit_price\x18\n \x01(\x01H\x06\x88\x01\x01\x12J\n\x14\x65xpiration_time_type\x18\x0b \x01(\x0e\x32\'.mt5_term_api.TMT5_ENUM_ORDER_TYPE_TIMEH\x07\x88\x01\x01\x12\x38\n\x0f\x65xpiration_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x42\x08\n\x06_priceB\x0b\n\t_slippageB\x0c\n\n_stop_lossB\x0e\n\x0c_take_profitB\n\n\x08_commentB\x0c\n\n_expert_idB\x13\n\x11_stop_limit_priceB\x17\n\x15_expiration_time_typeB\x12\n\x10_expiration_time\"o\n\x0eOrderSendReply\x12+\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1b.mt5_term_api.OrderSendDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xfd\x01\n\rOrderSendData\x12\x15\n\rreturned_code\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x65\x61l\x18\x02 \x01(\x04\x12\r\n\x05order\x18\x03 \x01(\x04\x12\x0e\n\x06volume\x18\x04 \x01(\x01\x12\r\n\x05price\x18\x05 \x01(\x01\x12\x0b\n\x03\x62id\x18\x06 \x01(\x01\x12\x0b\n\x03\x61sk\x18\x07 \x01(\x01\x12\x0f\n\x07\x63omment\x18\x08 \x01(\t\x12\x12\n\nrequest_id\x18\t \x01(\r\x12\x19\n\x11ret_code_external\x18\n \x01(\x05\x12\x1c\n\x14returned_string_code\x18\x0b \x01(\t\x12!\n\x19returned_code_description\x18\x0c \x01(\t*x\n\x15MRPC_ORDER_CLOSE_MODE\x12\x1b\n\x17MRPC_MARKET_ORDER_CLOSE\x10\x00\x12#\n\x1fMRPC_MARKET_ORDER_PARTIAL_CLOSE\x10\x01\x12\x1d\n\x19MRPC_PENDING_ORDER_REMOVE\x10\x02*\xac\x02\n\x14TMT5_ENUM_ORDER_TYPE\x12\x17\n\x13TMT5_ORDER_TYPE_BUY\x10\x00\x12\x18\n\x14TMT5_ORDER_TYPE_SELL\x10\x01\x12\x1d\n\x19TMT5_ORDER_TYPE_BUY_LIMIT\x10\x02\x12\x1e\n\x1aTMT5_ORDER_TYPE_SELL_LIMIT\x10\x03\x12\x1c\n\x18TMT5_ORDER_TYPE_BUY_STOP\x10\x04\x12\x1d\n\x19TMT5_ORDER_TYPE_SELL_STOP\x10\x05\x12\"\n\x1eTMT5_ORDER_TYPE_BUY_STOP_LIMIT\x10\x06\x12#\n\x1fTMT5_ORDER_TYPE_SELL_STOP_LIMIT\x10\x07\x12\x1c\n\x18TMT5_ORDER_TYPE_CLOSE_BY\x10\x08*\x8f\x01\n\x19TMT5_ENUM_ORDER_TYPE_TIME\x12\x17\n\x13TMT5_ORDER_TIME_GTC\x10\x00\x12\x17\n\x13TMT5_ORDER_TIME_DAY\x10\x01\x12\x1d\n\x19TMT5_ORDER_TIME_SPECIFIED\x10\x02\x12!\n\x1dTMT5_ORDER_TIME_SPECIFIED_DAY\x10\x03\x32\xb8\x02\n\rTradingHelper\x12]\n\tOrderSend\x12\x1e.mt5_term_api.OrderSendRequest\x1a\x1c.mt5_term_api.OrderSendReply\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/OrderSend\x12\x65\n\x0bOrderModify\x12 .mt5_term_api.OrderModifyRequest\x1a\x1e.mt5_term_api.OrderModifyReply\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/OrderModify\x12\x61\n\nOrderClose\x12\x1f.mt5_term_api.OrderCloseRequest\x1a\x1d.mt5_term_api.OrderCloseReply\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/OrderCloseBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_trading_helper_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _TRADINGHELPER.methods_by_name['OrderSend']._options = None
  _TRADINGHELPER.methods_by_name['OrderSend']._serialized_options = b'\202\323\344\223\002\014\022\n/OrderSend'
  _TRADINGHELPER.methods_by_name['OrderModify']._options = None
  _TRADINGHELPER.methods_by_name['OrderModify']._serialized_options = b'\202\323\344\223\002\016\022\014/OrderModify'
  _TRADINGHELPER.methods_by_name['OrderClose']._options = None
  _TRADINGHELPER.methods_by_name['OrderClose']._serialized_options = b'\202\323\344\223\002\r\022\013/OrderClose'
  _MRPC_ORDER_CLOSE_MODE._serialized_start=2155
  _MRPC_ORDER_CLOSE_MODE._serialized_end=2275
  _TMT5_ENUM_ORDER_TYPE._serialized_start=2278
  _TMT5_ENUM_ORDER_TYPE._serialized_end=2578
  _TMT5_ENUM_ORDER_TYPE_TIME._serialized_start=2581
  _TMT5_ENUM_ORDER_TYPE_TIME._serialized_end=2724
  _ORDERCLOSEREQUEST._serialized_start=136
  _ORDERCLOSEREQUEST._serialized_end=205
  _ORDERCLOSEREPLY._serialized_start=207
  _ORDERCLOSEREPLY._serialized_end=320
  _ORDERCLOSEDATA._serialized_start=323
  _ORDERCLOSEDATA._serialized_end=484
  _ORDERMODIFYREQUEST._serialized_start=487
  _ORDERMODIFYREQUEST._serialized_end=852
  _ORDERMODIFYREPLY._serialized_start=854
  _ORDERMODIFYREPLY._serialized_end=969
  _ORDERMODIFYDATA._serialized_start=972
  _ORDERMODIFYDATA._serialized_end=1227
  _ORDERSENDREQUEST._serialized_start=1230
  _ORDERSENDREQUEST._serialized_end=1784
  _ORDERSENDREPLY._serialized_start=1786
  _ORDERSENDREPLY._serialized_end=1897
  _ORDERSENDDATA._serialized_start=1900
  _ORDERSENDDATA._serialized_end=2153
  _TRADINGHELPER._serialized_start=2727
  _TRADINGHELPER._serialized_end=3039
# @@protoc_insertion_point(module_scope)
