# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-health-check.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmt5-term-api-health-check.proto\x12\x0cmt5_term_api\"\x16\n\x14StopListeningRequest\"\x14\n\x12StopListeningReply\"\x14\n\x12HealthCheckRequest\"O\n\x10HealthCheckReply\x12\x1e\n\x16is_connected_to_server\x18\x01 \x01(\x08\x12\x1b\n\x13server_time_seconds\x18\x02 \x01(\x03\x32\xaa\x01\n\x06Health\x12I\n\x05\x43heck\x12 .mt5_term_api.HealthCheckRequest\x1a\x1e.mt5_term_api.HealthCheckReply\x12U\n\rStopListening\x12\".mt5_term_api.StopListeningRequest\x1a .mt5_term_api.StopListeningReplyBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_health_check_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _STOPLISTENINGREQUEST._serialized_start=49
  _STOPLISTENINGREQUEST._serialized_end=71
  _STOPLISTENINGREPLY._serialized_start=73
  _STOPLISTENINGREPLY._serialized_end=93
  _HEALTHCHECKREQUEST._serialized_start=95
  _HEALTHCHECKREQUEST._serialized_end=115
  _HEALTHCHECKREPLY._serialized_start=117
  _HEALTHCHECKREPLY._serialized_end=196
  _HEALTH._serialized_start=199
  _HEALTH._serialized_end=369
# @@protoc_insertion_point(module_scope)
