# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mrpc-mt5-error.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14mrpc-mt5-error.proto\x12\x0cmt5_term_api\"\xc2\x03\n\x05\x45rror\x12%\n\x04type\x18\x01 \x01(\x0e\x32\x17.mt5_term_api.ErrorType\x12\x12\n\nerror_code\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x32\n\x0emql_error_code\x18\x04 \x01(\x0e\x32\x1a.mt5_term_api.MqlErrorCode\x12\x1a\n\x12mql_error_int_code\x18\x05 \x01(\x05\x12\x1d\n\x15mql_error_description\x18\x06 \x01(\t\x12=\n\x14mql_error_trade_code\x18\x07 \x01(\x0e\x32\x1f.mt5_term_api.MqlErrorTradeCode\x12 \n\x18mql_error_trade_int_code\x18\x08 \x01(\x05\x12#\n\x1bmql_error_trade_description\x18\t \x01(\t\x12\x13\n\x0bstack_trace\x18\n \x01(\t\x12\x19\n\x11\x63ommand_type_name\x18\x0b \x01(\t\x12\x11\n\tcommandId\x18\x0c \x01(\x03\x12/\n\nproperties\x18\r \x03(\x0b\x32\x1b.mt5_term_api.ErrorProperty\"?\n\rErrorProperty\x12\x15\n\rerror_arg_key\x18\x01 \x01(\t\x12\x17\n\x0f\x65rror_arg_value\x18\x02 \x01(\t\"h\n\x0bLogFileInfo\x12\'\n\x08log_type\x18\x01 \x01(\x0e\x32\x15.mt5_term_api.LogType\x12\x11\n\tfull_path\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t*\x82\x02\n\tErrorType\x12\r\n\tUNDEFINED\x10\x00\x12\x08\n\x04MRPC\x10\x01\x12\x13\n\x0fMRPC_VALIDATION\x10\x02\x12\x10\n\x0cMRPC_TIMEOUT\x10\x03\x12\x18\n\x14TERMINAL_API_TIMEOUT\x10\x04\x12\x1b\n\x17TERMINAL_API_GET_PARAMS\x10\x05\x12\x1b\n\x17TERMINAL_API_SET_RESULT\x10\x06\x12\x1b\n\x17TERMINAL_API_UNEXPECTED\x10\x07\x12\x11\n\rMQL_EXECUTION\x10\x08\x12\x18\n\x14MQL_CUSTOM_EXECUTION\x10\t\x12\x17\n\x13MQL_TRADE_EXECUTION\x10\n*)\n\x07LogType\x12\n\n\x06Global\x10\x00\x12\x08\n\x04MQL5\x10\x01\x12\x08\n\x04MQL4\x10\x02*\xe3\x31\n\x0cMqlErrorCode\x12\x0f\n\x0b\x45RR_SUCCESS\x10\x00\x12\x17\n\x12\x45RR_INTERNAL_ERROR\x10\xa1\x1f\x12!\n\x1c\x45RR_WRONG_INTERNAL_PARAMETER\x10\xa2\x1f\x12\x1a\n\x15\x45RR_INVALID_PARAMETER\x10\xa3\x1f\x12\x1a\n\x15\x45RR_NOT_ENOUGH_MEMORY\x10\xa4\x1f\x12#\n\x1e\x45RR_STRUCT_WITHOBJECTS_ORCLASS\x10\xa5\x1f\x12\x16\n\x11\x45RR_INVALID_ARRAY\x10\xa6\x1f\x12\x1b\n\x16\x45RR_ARRAY_RESIZE_ERROR\x10\xa7\x1f\x12\x1c\n\x17\x45RR_STRING_RESIZE_ERROR\x10\xa8\x1f\x12\x1e\n\x19\x45RR_NOTINITIALIZED_STRING\x10\xa9\x1f\x12\x19\n\x14\x45RR_INVALID_DATETIME\x10\xaa\x1f\x12\x17\n\x12\x45RR_ARRAY_BAD_SIZE\x10\xab\x1f\x12\x18\n\x13\x45RR_INVALID_POINTER\x10\xac\x1f\x12\x1d\n\x18\x45RR_INVALID_POINTER_TYPE\x10\xad\x1f\x12\x1d\n\x18\x45RR_FUNCTION_NOT_ALLOWED\x10\xae\x1f\x12!\n\x1c\x45RR_RESOURCE_NAME_DUPLICATED\x10\xaf\x1f\x12\x1b\n\x16\x45RR_RESOURCE_NOT_FOUND\x10\xb0\x1f\x12\"\n\x1d\x45RR_RESOURCE_UNSUPPORTED_TYPE\x10\xb1\x1f\x12\"\n\x1d\x45RR_RESOURCE_NAME_IS_TOO_LONG\x10\xb2\x1f\x12\x16\n\x11\x45RR_MATH_OVERFLOW\x10\xb3\x1f\x12\x14\n\x0f\x45RR_SLEEP_ERROR\x10\xb4\x1f\x12\x18\n\x13\x45RR_PROGRAM_STOPPED\x10\xb6\x1f\x12\x15\n\x10\x45RR_INVALID_TYPE\x10\xb7\x1f\x12\x17\n\x12\x45RR_INVALID_HANDLE\x10\xb8\x1f\x12\x19\n\x14\x45RR_TOO_MANY_OBJECTS\x10\xb9\x1f\x12\x17\n\x12\x45RR_CHART_WRONG_ID\x10\x85 \x12\x17\n\x12\x45RR_CHART_NO_REPLY\x10\x86 \x12\x18\n\x13\x45RR_CHART_NOT_FOUND\x10\x87 \x12\x18\n\x13\x45RR_CHART_NO_EXPERT\x10\x88 \x12\x1a\n\x15\x45RR_CHART_CANNOT_OPEN\x10\x89 \x12\x1c\n\x17\x45RR_CHART_CANNOT_CHANGE\x10\x8a \x12\x1e\n\x19\x45RR_CHART_WRONG_PARAMETER\x10\x8b \x12\"\n\x1d\x45RR_CHART_CANNOT_CREATE_TIMER\x10\x8c \x12\x1d\n\x18\x45RR_CHART_WRONG_PROPERTY\x10\x8d \x12 \n\x1b\x45RR_CHART_SCREENSHOT_FAILED\x10\x8e \x12\x1e\n\x19\x45RR_CHART_NAVIGATE_FAILED\x10\x8f \x12\x1e\n\x19\x45RR_CHART_TEMPLATE_FAILED\x10\x90 \x12\x1f\n\x1a\x45RR_CHART_WINDOW_NOT_FOUND\x10\x91 \x12#\n\x1e\x45RR_CHART_INDICATOR_CANNOT_ADD\x10\x92 \x12#\n\x1e\x45RR_CHART_INDICATOR_CANNOT_DEL\x10\x93 \x12\"\n\x1d\x45RR_CHART_INDICATOR_NOT_FOUND\x10\x94 \x12\x15\n\x10\x45RR_OBJECT_ERROR\x10\xe9 \x12\x19\n\x14\x45RR_OBJECT_NOT_FOUND\x10\xea \x12\x1e\n\x19\x45RR_OBJECT_WRONG_PROPERTY\x10\xeb \x12\x1e\n\x19\x45RR_OBJECT_GETDATE_FAILED\x10\xec \x12\x1f\n\x1a\x45RR_OBJECT_GETVALUE_FAILED\x10\xed \x12\x1e\n\x19\x45RR_MARKET_UNKNOWN_SYMBOL\x10\xcd!\x12\x1c\n\x17\x45RR_MARKET_NOT_SELECTED\x10\xce!\x12\x1e\n\x19\x45RR_MARKET_WRONG_PROPERTY\x10\xcf!\x12 \n\x1b\x45RR_MARKET_LASTTIME_UNKNOWN\x10\xd0!\x12\x1c\n\x17\x45RR_MARKET_SELECT_ERROR\x10\xd1!\x12\x1c\n\x17\x45RR_MARKET_SELECT_LIMIT\x10\xd2!\x12\x1d\n\x18\x45RR_MARKET_SESSION_INDEX\x10\xd3!\x12\x1a\n\x15\x45RR_HISTORY_NOT_FOUND\x10\xb1\"\x12\x1f\n\x1a\x45RR_HISTORY_WRONG_PROPERTY\x10\xb2\"\x12\x18\n\x13\x45RR_HISTORY_TIMEOUT\x10\xb3\"\x12\x1b\n\x16\x45RR_HISTORY_BARS_LIMIT\x10\xb4\"\x12\x1c\n\x17\x45RR_HISTORY_LOAD_ERRORS\x10\xb5\"\x12\x1d\n\x18\x45RR_HISTORY_SMALL_BUFFER\x10\xb7\"\x12!\n\x1c\x45RR_GLOBALVARIABLE_NOT_FOUND\x10\x95#\x12\x1e\n\x19\x45RR_GLOBALVARIABLE_EXISTS\x10\x96#\x12$\n\x1f\x45RR_GLOBALVARIABLE_NOT_MODIFIED\x10\x97#\x12\"\n\x1d\x45RR_GLOBALVARIABLE_CANNOTREAD\x10\x98#\x12#\n\x1e\x45RR_GLOBALVARIABLE_CANNOTWRITE\x10\x99#\x12\x19\n\x14\x45RR_MAIL_SEND_FAILED\x10\x9e#\x12\x1a\n\x15\x45RR_PLAY_SOUND_FAILED\x10\x9f#\x12\x1c\n\x17\x45RR_MQL5_WRONG_PROPERTY\x10\xa0#\x12 \n\x1b\x45RR_TERMINAL_WRONG_PROPERTY\x10\xa1#\x12\x18\n\x13\x45RR_FTP_SEND_FAILED\x10\xa2#\x12!\n\x1c\x45RR_NOTIFICATION_SEND_FAILED\x10\xa3#\x12%\n ERR_NOTIFICATION_WRONG_PARAMETER\x10\xa4#\x12$\n\x1f\x45RR_NOTIFICATION_WRONG_SETTINGS\x10\xa5#\x12\"\n\x1d\x45RR_NOTIFICATION_TOO_FREQUENT\x10\xa6#\x12\x15\n\x10\x45RR_FTP_NOSERVER\x10\xa7#\x12\x14\n\x0f\x45RR_FTP_NOLOGIN\x10\xa8#\x12\x17\n\x12\x45RR_FTP_FILE_ERROR\x10\xa9#\x12\x1b\n\x16\x45RR_FTP_CONNECT_FAILED\x10\xaa#\x12\x16\n\x11\x45RR_FTP_CHANGEDIR\x10\xab#\x12\x1a\n\x15\x45RR_BUFFERS_NO_MEMORY\x10\xf9#\x12\x1c\n\x17\x45RR_BUFFERS_WRONG_INDEX\x10\xfa#\x12\x1e\n\x19\x45RR_CUSTOM_WRONG_PROPERTY\x10\xfb#\x12\x1f\n\x1a\x45RR_ACCOUNT_WRONG_PROPERTY\x10\xdd$\x12\x1d\n\x18\x45RR_TRADE_WRONG_PROPERTY\x10\x8f%\x12\x17\n\x12\x45RR_TRADE_DISABLED\x10\x90%\x12!\n\x1c\x45RR_TRADE_POSITION_NOT_FOUND\x10\x91%\x12\x1e\n\x19\x45RR_TRADE_ORDER_NOT_FOUND\x10\x92%\x12\x1d\n\x18\x45RR_TRADE_DEAL_NOT_FOUND\x10\x93%\x12\x1a\n\x15\x45RR_TRADE_SEND_FAILED\x10\x94%\x12\x1a\n\x15\x45RR_TRADE_CALC_FAILED\x10\x96%\x12!\n\x1c\x45RR_INDICATOR_UNKNOWN_SYMBOL\x10\xc1%\x12 \n\x1b\x45RR_INDICATOR_CANNOT_CREATE\x10\xc2%\x12\x1c\n\x17\x45RR_INDICATOR_NO_MEMORY\x10\xc3%\x12\x1f\n\x1a\x45RR_INDICATOR_CANNOT_APPLY\x10\xc4%\x12\x1d\n\x18\x45RR_INDICATOR_CANNOT_ADD\x10\xc5%\x12!\n\x1c\x45RR_INDICATOR_DATA_NOT_FOUND\x10\xc6%\x12\x1f\n\x1a\x45RR_INDICATOR_WRONG_HANDLE\x10\xc7%\x12#\n\x1e\x45RR_INDICATOR_WRONG_PARAMETERS\x10\xc8%\x12\x19\n\x14\x45RR_BOOKS_CANNOT_ADD\x10\xa5&\x12\x1c\n\x17\x45RR_BOOKS_CANNOT_DELETE\x10\xa6&\x12\x19\n\x14\x45RR_BOOKS_CANNOT_GET\x10\xa7&\x12\x1f\n\x1a\x45RR_BOOKS_CANNOT_SUBSCRIBE\x10\xa8&\x12\x17\n\x12\x45RR_TOO_MANY_FILES\x10\x89\'\x12\x17\n\x12\x45RR_WRONG_FILENAME\x10\x8a\'\x12\x1a\n\x15\x45RR_TOO_LONG_FILENAME\x10\x8b\'\x12\x19\n\x14\x45RR_CANNOT_OPEN_FILE\x10\x8c\'\x12\x1f\n\x1a\x45RR_FILE_CACHEBUFFER_ERROR\x10\x8d\'\x12\x1b\n\x16\x45RR_CANNOT_DELETE_FILE\x10\x8e\'\x12\x1b\n\x16\x45RR_INVALID_FILEHANDLE\x10\x8f\'\x12\x19\n\x14\x45RR_WRONG_FILEHANDLE\x10\x90\'\x12\x17\n\x12\x45RR_NO_STRING_DATE\x10\xa6\'\x12\x1a\n\x15\x45RR_WRONG_STRING_DATE\x10\xa7\'\x12\x1a\n\x15\x45RR_WRONG_STRING_TIME\x10\xa8\'\x12\x1a\n\x15\x45RR_STRING_TIME_ERROR\x10\xa9\'\x12\x1d\n\x18\x45RR_STRING_OUT_OF_MEMORY\x10\xaa\'\x12\x1c\n\x17\x45RR_INCOMPATIBLE_ARRAYS\x10\xba\'\x12\x1d\n\x18\x45RR_SMALL_ASSERIES_ARRAY\x10\xbb\'\x12\x14\n\x0f\x45RR_SMALL_ARRAY\x10\xbc\'\x12\x17\n\x12\x45RR_ZEROSIZE_ARRAY\x10\xbd\'\x12\x1b\n\x16\x45RR_NUMBER_ARRAYS_ONLY\x10\xbe\'\x12\x1d\n\x18\x45RR_OPENCL_NOT_SUPPORTED\x10\xec\'\x12\x18\n\x13\x45RR_OPENCL_INTERNAL\x10\xed\'\x12\x1e\n\x19\x45RR_OPENCL_INVALID_HANDLE\x10\xee\'\x12\x1e\n\x19\x45RR_OPENCL_CONTEXT_CREATE\x10\xef\'\x12\x1c\n\x17\x45RR_OPENCL_QUEUE_CREATE\x10\xf0\'\x12\x1e\n\x19\x45RR_OPENCL_PROGRAM_CREATE\x10\xf1\'\x12$\n\x1f\x45RR_OPENCL_TOO_LONG_KERNEL_NAME\x10\xf2\'\x12\x1d\n\x18\x45RR_OPENCL_KERNEL_CREATE\x10\xf3\'\x12$\n\x1f\x45RR_OPENCL_SET_KERNEL_PARAMETER\x10\xf4\'\x12\x17\n\x12\x45RR_OPENCL_EXECUTE\x10\xf5\'\x12!\n\x1c\x45RR_OPENCL_WRONG_BUFFER_SIZE\x10\xf6\'\x12#\n\x1e\x45RR_OPENCL_WRONG_BUFFER_OFFSET\x10\xf7\'\x12\x1d\n\x18\x45RR_OPENCL_BUFFER_CREATE\x10\xf8\'\x12 \n\x1b\x45RR_OPENCL_TOO_MANY_OBJECTS\x10\xf9\'\x12\x1c\n\x17\x45RR_OPENCL_SELECTDEVICE\x10\xfa\'\x12\x1a\n\x15\x45RR_DATABASE_INTERNAL\x10\x80(\x12 \n\x1b\x45RR_DATABASE_INVALID_HANDLE\x10\x81(\x12\"\n\x1d\x45RR_DATABASE_TOO_MANY_OBJECTS\x10\x82(\x12\x19\n\x14\x45RR_DATABASE_CONNECT\x10\x83(\x12\x19\n\x14\x45RR_DATABASE_EXECUTE\x10\x84(\x12\x19\n\x14\x45RR_DATABASE_PREPARE\x10\x85(\x12\x1e\n\x19\x45RR_DATABASE_NO_MORE_DATA\x10\x86(\x12\x16\n\x11\x45RR_DATABASE_STEP\x10\x87(\x12\x1b\n\x16\x45RR_DATABASE_NOT_READY\x10\x88(\x12!\n\x1c\x45RR_DATABASE_BIND_PARAMETERS\x10\x89(\x12#\n\x1e\x45RR_WEBREQUEST_INVALID_ADDRESS\x10\xd0(\x12\"\n\x1d\x45RR_WEBREQUEST_CONNECT_FAILED\x10\xd1(\x12\x1b\n\x16\x45RR_WEBREQUEST_TIMEOUT\x10\xd2(\x12\"\n\x1d\x45RR_WEBREQUEST_REQUEST_FAILED\x10\xd3(\x12 \n\x1b\x45RR_NETSOCKET_INVALIDHANDLE\x10\x96)\x12\"\n\x1d\x45RR_NETSOCKET_TOO_MANY_OPENED\x10\x97)\x12!\n\x1c\x45RR_NETSOCKET_CANNOT_CONNECT\x10\x98)\x12\x1b\n\x16\x45RR_NETSOCKET_IO_ERROR\x10\x99)\x12#\n\x1e\x45RR_NETSOCKET_HANDSHAKE_FAILED\x10\x9a)\x12!\n\x1c\x45RR_NETSOCKET_NO_CERTIFICATE\x10\x9b)\x12\x1a\n\x15\x45RR_NOT_CUSTOM_SYMBOL\x10\xb4)\x12!\n\x1c\x45RR_CUSTOM_SYMBOL_WRONG_NAME\x10\xb5)\x12 \n\x1b\x45RR_CUSTOM_SYMBOL_NAME_LONG\x10\xb6)\x12 \n\x1b\x45RR_CUSTOM_SYMBOL_PATH_LONG\x10\xb7)\x12\x1c\n\x17\x45RR_CUSTOM_SYMBOL_EXIST\x10\xb8)\x12\x1c\n\x17\x45RR_CUSTOM_SYMBOL_ERROR\x10\xb9)\x12\x1f\n\x1a\x45RR_CUSTOM_SYMBOL_SELECTED\x10\xba)\x12%\n ERR_CUSTOM_SYMBOL_PROPERTY_WRONG\x10\xbb)\x12&\n!ERR_CUSTOM_SYMBOL_PARAMETER_ERROR\x10\xbc)\x12%\n ERR_CUSTOM_SYMBOL_PARAMETER_LONG\x10\xbd)\x12!\n\x1c\x45RR_CUSTOM_TICKS_WRONG_ORDER\x10\xbe)\x12\x1b\n\x16\x45RR_CALENDAR_MORE_DATA\x10\x98*\x12\x19\n\x14\x45RR_CALENDAR_TIMEOUT\x10\x99*\x12\x19\n\x14\x45RR_CALENDAR_NO_DATA\x10\x9a*\x12\x17\n\x12\x45RR_DATABASE_ERROR\x10\xe1+\x12\x17\n\x12\x45RR_DATABASE_LOGIC\x10\xe2+\x12\x16\n\x11\x45RR_DATABASE_PERM\x10\xe3+\x12\x17\n\x12\x45RR_DATABASE_ABORT\x10\xe4+\x12\x16\n\x11\x45RR_DATABASE_BUSY\x10\xe5+\x12\x18\n\x13\x45RR_DATABASE_LOCKED\x10\xe6+\x12\x17\n\x12\x45RR_DATABASE_NOMEM\x10\xe7+\x12\x1a\n\x15\x45RR_DATABASE_READONLY\x10\xe8+\x12\x1b\n\x16\x45RR_DATABASE_INTERRUPT\x10\xe9+\x12\x17\n\x12\x45RR_DATABASE_IOERR\x10\xea+\x12\x19\n\x14\x45RR_DATABASE_CORRUPT\x10\xeb+\x12\x1a\n\x15\x45RR_DATABASE_NOTFOUND\x10\xec+\x12\x16\n\x11\x45RR_DATABASE_FULL\x10\xed+\x12\x1a\n\x15\x45RR_DATABASE_CANTOPEN\x10\xee+\x12\x1a\n\x15\x45RR_DATABASE_PROTOCOL\x10\xef+\x12\x17\n\x12\x45RR_DATABASE_EMPTY\x10\xf0+\x12\x18\n\x13\x45RR_DATABASE_SCHEMA\x10\xf1+\x12\x18\n\x13\x45RR_DATABASE_TOOBIG\x10\xf2+\x12\x1c\n\x17\x45RR_DATABASE_CONSTRAINT\x10\xf3+\x12\x1a\n\x15\x45RR_DATABASE_MISMATCH\x10\xf4+\x12\x18\n\x13\x45RR_DATABASE_MISUSE\x10\xf5+\x12\x17\n\x12\x45RR_DATABASE_NOLFS\x10\xf6+\x12\x16\n\x11\x45RR_DATABASE_AUTH\x10\xf7+\x12\x18\n\x13\x45RR_DATABASE_FORMAT\x10\xf8+\x12\x17\n\x12\x45RR_DATABASE_RANGE\x10\xf9+\x12\x18\n\x13\x45RR_DATABASE_NOTADB\x10\xfa+\x12\x18\n\x13\x45RR_MATRIX_INTERNAL\x10\xc4,\x12\x1f\n\x1a\x45RR_MATRIX_NOT_INITIALIZED\x10\xc5,\x12\x1c\n\x17\x45RR_MATRIX_INCONSISTENT\x10\xc6,\x12\x1c\n\x17\x45RR_MATRIX_INVALID_SIZE\x10\xc7,\x12\x1c\n\x17\x45RR_MATRIX_INVALID_TYPE\x10\xc8,\x12 \n\x1b\x45RR_MATRIX_FUNC_NOT_ALLOWED\x10\xc9,\x12\x1c\n\x17\x45RR_MATRIX_CONTAINS_NAN\x10\xca,\x12\x16\n\x11\x45RR_ONNX_INTERNAL\x10\xa8-\x12\x1d\n\x18\x45RR_ONNX_NOT_INITIALIZED\x10\xa9-\x12\x1b\n\x16\x45RR_ONNX_NOT_SUPPORTED\x10\xaa-\x12\x18\n\x13\x45RR_ONNX_RUN_FAILED\x10\xab-\x12&\n!ERR_ONNX_INVALID_PARAMETERS_COUNT\x10\xac-\x12\x1f\n\x1a\x45RR_ONNX_INVALID_PARAMETER\x10\xad-\x12$\n\x1f\x45RR_ONNX_INVALID_PARAMETER_TYPE\x10\xae-\x12$\n\x1f\x45RR_ONNX_INVALID_PARAMETER_SIZE\x10\xaf-\x12\x1d\n\x18\x45RR_ONNX_WRONG_DIMENSION\x10\xb0-\x12\x1a\n\x14\x45RR_USER_ERROR_FIRST\x10\x80\x80\x04*\xdd\n\n\x11MqlErrorTradeCode\x12\x19\n\x15TRADE_RETCODE_SUCCESS\x10\x00\x12\x1a\n\x15TRADE_RETCODE_REQUOTE\x10\x94N\x12\x19\n\x14TRADE_RETCODE_REJECT\x10\x96N\x12\x19\n\x14TRADE_RETCODE_CANCEL\x10\x97N\x12\x19\n\x14TRADE_RETCODE_PLACED\x10\x98N\x12\x17\n\x12TRADE_RETCODE_DONE\x10\x99N\x12\x1f\n\x1aTRADE_RETCODE_DONE_PARTIAL\x10\x9aN\x12\x18\n\x13TRADE_RETCODE_ERROR\x10\x9bN\x12\x1a\n\x15TRADE_RETCODE_TIMEOUT\x10\x9cN\x12\x1a\n\x15TRADE_RETCODE_INVALID\x10\x9dN\x12!\n\x1cTRADE_RETCODE_INVALID_VOLUME\x10\x9eN\x12 \n\x1bTRADE_RETCODE_INVALID_PRICE\x10\x9fN\x12 \n\x1bTRADE_RETCODE_INVALID_STOPS\x10\xa0N\x12!\n\x1cTRADE_RETCODE_TRADE_DISABLED\x10\xa1N\x12 \n\x1bTRADE_RETCODE_MARKET_CLOSED\x10\xa2N\x12\x1b\n\x16TRADE_RETCODE_NO_MONEY\x10\xa3N\x12 \n\x1bTRADE_RETCODE_PRICE_CHANGED\x10\xa4N\x12\x1c\n\x17TRADE_RETCODE_PRICE_OFF\x10\xa5N\x12%\n TRADE_RETCODE_INVALID_EXPIRATION\x10\xa6N\x12 \n\x1bTRADE_RETCODE_ORDER_CHANGED\x10\xa7N\x12$\n\x1fTRADE_RETCODE_TOO_MANY_REQUESTS\x10\xa8N\x12\x1d\n\x18TRADE_RETCODE_NO_CHANGES\x10\xa9N\x12%\n TRADE_RETCODE_SERVER_DISABLES_AT\x10\xaaN\x12%\n TRADE_RETCODE_CLIENT_DISABLES_AT\x10\xabN\x12\x19\n\x14TRADE_RETCODE_LOCKED\x10\xacN\x12\x19\n\x14TRADE_RETCODE_FROZEN\x10\xadN\x12\x1f\n\x1aTRADE_RETCODE_INVALID_FILL\x10\xaeN\x12\x1d\n\x18TRADE_RETCODE_CONNECTION\x10\xafN\x12\x1c\n\x17TRADE_RETCODE_ONLY_REAL\x10\xb0N\x12\x1f\n\x1aTRADE_RETCODE_LIMIT_ORDERS\x10\xb1N\x12\x1f\n\x1aTRADE_RETCODE_LIMIT_VOLUME\x10\xb2N\x12 \n\x1bTRADE_RETCODE_INVALID_ORDER\x10\xb3N\x12\"\n\x1dTRADE_RETCODE_POSITION_CLOSED\x10\xb4N\x12\'\n\"TRADE_RETCODE_INVALID_CLOSE_VOLUME\x10\xb6N\x12$\n\x1fTRADE_RETCODE_CLOSE_ORDER_EXIST\x10\xb7N\x12\"\n\x1dTRADE_RETCODE_LIMIT_POSITIONS\x10\xb8N\x12 \n\x1bTRADE_RETCODE_REJECT_CANCEL\x10\xb9N\x12\x1c\n\x17TRADE_RETCODE_LONG_ONLY\x10\xbaN\x12\x1d\n\x18TRADE_RETCODE_SHORT_ONLY\x10\xbbN\x12\x1d\n\x18TRADE_RETCODE_CLOSE_ONLY\x10\xbcN\x12\x1d\n\x18TRADE_RETCODE_FIFO_CLOSE\x10\xbdN\x12#\n\x1eTRADE_RETCODE_HEDGE_PROHIBITED\x10\xbeNB3Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/gob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mrpc_mt5_error_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go'
  _ERRORTYPE._serialized_start=663
  _ERRORTYPE._serialized_end=921
  _LOGTYPE._serialized_start=923
  _LOGTYPE._serialized_end=964
  _MQLERRORCODE._serialized_start=967
  _MQLERRORCODE._serialized_end=7338
  _MQLERRORTRADECODE._serialized_start=7341
  _MQLERRORTRADECODE._serialized_end=8714
  _ERROR._serialized_start=39
  _ERROR._serialized_end=489
  _ERRORPROPERTY._serialized_start=491
  _ERRORPROPERTY._serialized_end=554
  _LOGFILEINFO._serialized_start=556
  _LOGFILEINFO._serialized_end=660
# @@protoc_insertion_point(module_scope)
