# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-connection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import mrpc_mt5_error_pb2 as mrpc__mt5__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dmt5-term-api-connection.proto\x12\x0cmt5_term_api\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x14mrpc-mt5-error.proto\"\x9e\x02\n\x10\x43onnectExRequest\x12\x0c\n\x04user\x18\x01 \x01(\x04\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x17\n\x0fmt_cluster_name\x18\x03 \x01(\t\x12\x1e\n\x11\x62\x61se_chart_symbol\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x37\n*terminal_readiness_waiting_timeout_seconds\x18\x05 \x01(\x05H\x01\x88\x01\x01\x12\x33\n\x0e\x65xperts_to_add\x18\x06 \x03(\x0b\x32\x1b.mt5_term_api.ExpertAdviserB\x14\n\x12_base_chart_symbolB-\n+_terminal_readiness_waiting_timeout_seconds\"m\n\x0e\x43onnectExReply\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x19.mt5_term_api.ConnectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xb2\x01\n\x10ReconnectRequest\x12\x1f\n\x12\x66orce_reconnection\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x37\n*terminal_readiness_waiting_timeout_seconds\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x15\n\x13_force_reconnectionB-\n+_terminal_readiness_waiting_timeout_seconds\"o\n\x0eReconnectReply\x12+\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1b.mt5_term_api.ReconnectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xe1\x01\n\rReconnectData\x12\x1e\n\x16terminal_was_recreated\x18\x01 \x01(\x08\x12\x31\n\rterminal_type\x18\x02 \x01(\x0e\x32\x1a.mt5_term_api.TerminalType\x12\x1e\n\x16terminal_instance_guid\x18\x03 \x01(\t\x12+\n#old_terminal_full_live_time_seconds\x18\x04 \x01(\x03\x12\x30\n\rold_log_files\x18\x05 \x03(\x0b\x32\x19.mt5_term_api.LogFileInfo\"\xe7\x02\n\x0e\x43onnectRequest\x12\x0c\n\x04user\x18\x01 \x01(\x04\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x1e\n\x11\x62\x61se_chart_symbol\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\'\n\x1await_for_terminal_is_alive\x18\x06 \x01(\x08H\x01\x88\x01\x01\x12\x37\n*terminal_readiness_waiting_timeout_seconds\x18\x07 \x01(\x05H\x02\x88\x01\x01\x12\x33\n\x0e\x65xperts_to_add\x18\x08 \x03(\x0b\x32\x1b.mt5_term_api.ExpertAdviserB\x14\n\x12_base_chart_symbolB\x1d\n\x1b_wait_for_terminal_is_aliveB-\n+_terminal_readiness_waiting_timeout_seconds\"8\n\rExpertAdviser\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66ile_content\x18\x02 \x01(\x0c\"k\n\x0c\x43onnectReply\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x19.mt5_term_api.ConnectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"`\n\x0b\x43onnectData\x12\x1e\n\x16terminal_instance_guid\x18\x01 \x01(\t\x12\x31\n\rterminal_type\x18\x03 \x01(\x0e\x32\x1a.mt5_term_api.TerminalType\"\xe9\x03\n\x13\x43onnectProxyRequest\x12\x0c\n\x04user\x18\x01 \x01(\x04\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x11\n\tproxyUser\x18\x05 \x01(\t\x12\x15\n\rproxyPassword\x18\x06 \x01(\t\x12\x11\n\tproxyHost\x18\x07 \x01(\t\x12\x11\n\tproxyPort\x18\x08 \x01(\r\x12+\n\tproxyType\x18\t \x01(\x0e\x32\x18.mt5_term_api.ProxyTypes\x12\x1e\n\x11\x62\x61se_chart_symbol\x18\n \x01(\tH\x00\x88\x01\x01\x12\'\n\x1await_for_terminal_is_alive\x18\x0b \x01(\x08H\x01\x88\x01\x01\x12\x37\n*terminal_readiness_waiting_timeout_seconds\x18\x0c \x01(\x05H\x02\x88\x01\x01\x12\x33\n\x0e\x65xperts_to_add\x18\r \x03(\x0b\x32\x1b.mt5_term_api.ExpertAdviserB\x14\n\x12_base_chart_symbolB\x1d\n\x1b_wait_for_terminal_is_aliveB-\n+_terminal_readiness_waiting_timeout_seconds\"u\n\x11\x43onnectProxyReply\x12.\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1e.mt5_term_api.ConnectProxyDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"`\n\x10\x43onnectProxyData\x12\x19\n\x11unique_identifier\x18\x01 \x01(\t\x12\x31\n\rterminal_type\x18\x02 \x01(\x0e\x32\x1a.mt5_term_api.TerminalType\"\x15\n\x13\x43heckConnectRequest\"u\n\x11\x43heckConnectReply\x12.\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1e.mt5_term_api.CheckConnectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"f\n\x10\x43heckConnectData\x12\x19\n\x11unique_identifier\x18\x01 \x01(\t\x12\x37\n\x0chealth_check\x18\x02 \x01(\x0b\x32!.mt5_term_api.TerminalHealthCheck\"\xa1\x02\n\x13TerminalHealthCheck\x12\x10\n\x08is_alive\x18\x01 \x01(\x08\x12\x32\n\x0c\x45rrorMessage\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tErrorCode\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nStackTrace\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x17has_authorization_error\x18\x05 \x01(\x08\x12\x14\n\x0c\x61pi_is_alive\x18\x06 \x01(\x08\x12*\n\"terminal_is_connected_to_mt_server\x18\x07 \x01(\x08\"\x13\n\x11\x44isconnectRequest\"q\n\x0f\x44isconnectReply\x12,\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.mt5_term_api.DisconnectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"K\n\x0e\x44isconnectData\x12\x19\n\x11unique_identifier\x18\x01 \x01(\t\x12\x1e\n\x16\x66ull_life_time_seconds\x18\x02 \x01(\x03*9\n\nProxyTypes\x12\x08\n\x04None\x10\x00\x12\t\n\x05Https\x10\x01\x12\n\n\x06Socks4\x10\x02\x12\n\n\x06Socks5\x10\x03* \n\x0cTerminalType\x12\x07\n\x03MT4\x10\x00\x12\x07\n\x03MT5\x10\x01\x32\xda\x04\n\nConnection\x12]\n\tConnectEx\x12\x1e.mt5_term_api.ConnectExRequest\x1a\x1c.mt5_term_api.ConnectExReply\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/ConnectEx\x12U\n\x07\x43onnect\x12\x1c.mt5_term_api.ConnectRequest\x1a\x1a.mt5_term_api.ConnectReply\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/Connect\x12i\n\x0c\x43onnectProxy\x12!.mt5_term_api.ConnectProxyRequest\x1a\x1f.mt5_term_api.ConnectProxyReply\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/ConnectProxy\x12i\n\x0c\x43heckConnect\x12!.mt5_term_api.CheckConnectRequest\x1a\x1f.mt5_term_api.CheckConnectReply\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/CheckConnect\x12\x61\n\nDisconnect\x12\x1f.mt5_term_api.DisconnectRequest\x1a\x1d.mt5_term_api.DisconnectReply\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/Disconnect\x12]\n\tReconnect\x12\x1e.mt5_term_api.ReconnectRequest\x1a\x1c.mt5_term_api.ReconnectReply\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/ReconnectBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_connection_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _CONNECTION.methods_by_name['ConnectEx']._options = None
  _CONNECTION.methods_by_name['ConnectEx']._serialized_options = b'\202\323\344\223\002\014\022\n/ConnectEx'
  _CONNECTION.methods_by_name['Connect']._options = None
  _CONNECTION.methods_by_name['Connect']._serialized_options = b'\202\323\344\223\002\n\022\010/Connect'
  _CONNECTION.methods_by_name['ConnectProxy']._options = None
  _CONNECTION.methods_by_name['ConnectProxy']._serialized_options = b'\202\323\344\223\002\017\022\r/ConnectProxy'
  _CONNECTION.methods_by_name['CheckConnect']._options = None
  _CONNECTION.methods_by_name['CheckConnect']._serialized_options = b'\202\323\344\223\002\017\022\r/CheckConnect'
  _CONNECTION.methods_by_name['Disconnect']._options = None
  _CONNECTION.methods_by_name['Disconnect']._serialized_options = b'\202\323\344\223\002\r\022\013/Disconnect'
  _CONNECTION.methods_by_name['Reconnect']._options = None
  _CONNECTION.methods_by_name['Reconnect']._serialized_options = b'\202\323\344\223\002\014\022\n/Reconnect'
  _PROXYTYPES._serialized_start=3140
  _PROXYTYPES._serialized_end=3197
  _TERMINALTYPE._serialized_start=3199
  _TERMINALTYPE._serialized_end=3231
  _CONNECTEXREQUEST._serialized_start=132
  _CONNECTEXREQUEST._serialized_end=418
  _CONNECTEXREPLY._serialized_start=420
  _CONNECTEXREPLY._serialized_end=529
  _RECONNECTREQUEST._serialized_start=532
  _RECONNECTREQUEST._serialized_end=710
  _RECONNECTREPLY._serialized_start=712
  _RECONNECTREPLY._serialized_end=823
  _RECONNECTDATA._serialized_start=826
  _RECONNECTDATA._serialized_end=1051
  _CONNECTREQUEST._serialized_start=1054
  _CONNECTREQUEST._serialized_end=1413
  _EXPERTADVISER._serialized_start=1415
  _EXPERTADVISER._serialized_end=1471
  _CONNECTREPLY._serialized_start=1473
  _CONNECTREPLY._serialized_end=1580
  _CONNECTDATA._serialized_start=1582
  _CONNECTDATA._serialized_end=1678
  _CONNECTPROXYREQUEST._serialized_start=1681
  _CONNECTPROXYREQUEST._serialized_end=2170
  _CONNECTPROXYREPLY._serialized_start=2172
  _CONNECTPROXYREPLY._serialized_end=2289
  _CONNECTPROXYDATA._serialized_start=2291
  _CONNECTPROXYDATA._serialized_end=2387
  _CHECKCONNECTREQUEST._serialized_start=2389
  _CHECKCONNECTREQUEST._serialized_end=2410
  _CHECKCONNECTREPLY._serialized_start=2412
  _CHECKCONNECTREPLY._serialized_end=2529
  _CHECKCONNECTDATA._serialized_start=2531
  _CHECKCONNECTDATA._serialized_end=2633
  _TERMINALHEALTHCHECK._serialized_start=2636
  _TERMINALHEALTHCHECK._serialized_end=2925
  _DISCONNECTREQUEST._serialized_start=2927
  _DISCONNECTREQUEST._serialized_end=2946
  _DISCONNECTREPLY._serialized_start=2948
  _DISCONNECTREPLY._serialized_end=3061
  _DISCONNECTDATA._serialized_start=3063
  _DISCONNECTDATA._serialized_end=3138
  _CONNECTION._serialized_start=3234
  _CONNECTION._serialized_end=3836
# @@protoc_insertion_point(module_scope)
