# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-market-info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import mrpc_mt5_error_pb2 as mrpc__mt5__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1emt5-term-api-market-info.proto\x12\x0cmt5_term_api\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14mrpc-mt5-error.proto\"#\n\x13SymbolsTotalRequest\x12\x0c\n\x04mode\x18\x01 \x01(\x08\"u\n\x11SymbolsTotalReply\x12.\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1e.mt5_term_api.SymbolsTotalDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"!\n\x10SymbolsTotalData\x12\r\n\x05total\x18\x01 \x01(\x05\"\"\n\x12SymbolExistRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"s\n\x10SymbolExistReply\x12-\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1d.mt5_term_api.SymbolExistDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"4\n\x0fSymbolExistData\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x12\x11\n\tis_custom\x18\x02 \x01(\x08\"4\n\x11SymbolNameRequest\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x10\n\x08selected\x18\x02 \x01(\x08\"q\n\x0fSymbolNameReply\x12,\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.mt5_term_api.SymbolNameDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\x1e\n\x0eSymbolNameData\x12\x0c\n\x04name\x18\x01 \x01(\t\"5\n\x13SymbolSelectRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0e\n\x06select\x18\x02 \x01(\x08\"u\n\x11SymbolSelectReply\x12.\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1e.mt5_term_api.SymbolSelectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"#\n\x10SymbolSelectData\x12\x0f\n\x07success\x18\x01 \x01(\x08\"-\n\x1bSymbolIsSynchronizedRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\"\x85\x01\n\x19SymbolIsSynchronizedReply\x12\x36\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32&.mt5_term_api.SymbolIsSynchronizedDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"0\n\x18SymbolIsSynchronizedData\x12\x14\n\x0csynchronized\x18\x01 \x01(\x08\"_\n\x17SymbolInfoDoubleRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x34\n\x04type\x18\x02 \x01(\x0e\x32&.mt5_term_api.SymbolInfoDoubleProperty\"}\n\x15SymbolInfoDoubleReply\x12\x32\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\".mt5_term_api.SymbolInfoDoubleDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"%\n\x14SymbolInfoDoubleData\x12\r\n\x05value\x18\x01 \x01(\x01\"a\n\x18SymbolInfoIntegerRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x35\n\x04type\x18\x02 \x01(\x0e\x32\'.mt5_term_api.SymbolInfoIntegerProperty\"\x7f\n\x16SymbolInfoIntegerReply\x12\x33\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32#.mt5_term_api.SymbolInfoIntegerDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"&\n\x15SymbolInfoIntegerData\x12\r\n\x05value\x18\x01 \x01(\x03\"_\n\x17SymbolInfoStringRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x34\n\x04type\x18\x02 \x01(\x0e\x32&.mt5_term_api.SymbolInfoStringProperty\"}\n\x15SymbolInfoStringReply\x12\x32\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\".mt5_term_api.SymbolInfoStringDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"%\n\x14SymbolInfoStringData\x12\r\n\x05value\x18\x01 \x01(\t\"`\n\x1bSymbolInfoMarginRateRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x31\n\norder_type\x18\x02 \x01(\x0e\x32\x1d.mt5_term_api.ENUM_ORDER_TYPE\"\x85\x01\n\x19SymbolInfoMarginRateReply\x12\x36\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32&.mt5_term_api.SymbolInfoMarginRateDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"X\n\x18SymbolInfoMarginRateData\x12\x1f\n\x17maintenance_margin_rate\x18\x01 \x01(\x01\x12\x1b\n\x13initial_margin_rate\x18\x02 \x01(\x01\"\'\n\x15SymbolInfoTickRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\"y\n\x1aSymbolInfoTickRequestReply\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x19.mt5_term_api.MrpcMqlTickH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\x89\x01\n\x0bMrpcMqlTick\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12\x0b\n\x03\x62id\x18\x02 \x01(\x01\x12\x0b\n\x03\x61sk\x18\x03 \x01(\x01\x12\x0c\n\x04last\x18\x04 \x01(\x01\x12\x0e\n\x06volume\x18\x05 \x01(\x04\x12\x10\n\x08time_msc\x18\x06 \x01(\x03\x12\r\n\x05\x66lags\x18\x07 \x01(\r\x12\x13\n\x0bvolume_real\x18\x08 \x01(\x01\"t\n\x1dSymbolInfoSessionQuoteRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12,\n\x0b\x64\x61y_of_week\x18\x02 \x01(\x0e\x32\x17.mt5_term_api.DayOfWeek\x12\x15\n\rsession_index\x18\x03 \x01(\r\"\x89\x01\n\x1bSymbolInfoSessionQuoteReply\x12\x38\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32(.mt5_term_api.SymbolInfoSessionQuoteDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"n\n\x1aSymbolInfoSessionQuoteData\x12(\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02to\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"t\n\x1dSymbolInfoSessionTradeRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12,\n\x0b\x64\x61y_of_week\x18\x02 \x01(\x0e\x32\x17.mt5_term_api.DayOfWeek\x12\x15\n\rsession_index\x18\x03 \x01(\r\"\x89\x01\n\x1bSymbolInfoSessionTradeReply\x12\x38\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32(.mt5_term_api.SymbolInfoSessionTradeDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"n\n\x1aSymbolInfoSessionTradeData\x12(\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02to\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"&\n\x14MarketBookAddRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\"w\n\x12MarketBookAddReply\x12/\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1f.mt5_term_api.MarketBookAddDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"0\n\x11MarketBookAddData\x12\x1b\n\x13opened_successfully\x18\x01 \x01(\x08\"*\n\x18MarketBookReleaseRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\"\x7f\n\x16MarketBookReleaseReply\x12\x33\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32#.mt5_term_api.MarketBookReleaseDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"4\n\x15MarketBookReleaseData\x12\x1b\n\x13\x63losed_successfully\x18\x01 \x01(\x08\"&\n\x14MarketBookGetRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\"w\n\x12MarketBookGetReply\x12/\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1f.mt5_term_api.MarketBookGetDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"J\n\x11MarketBookGetData\x12\x35\n\x0emql_book_infos\x18\x01 \x03(\x0b\x32\x1d.mt5_term_api.MrpcMqlBookInfo\"k\n\x0fMrpcMqlBookInfo\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.mt5_term_api.BookType\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\x13\n\x0bvolume_real\x18\x04 \x01(\x01*\xb7\x0c\n\x18SymbolInfoDoubleProperty\x12\x0e\n\nSYMBOL_BID\x10\x00\x12\x12\n\x0eSYMBOL_BIDHIGH\x10\x01\x12\x11\n\rSYMBOL_BIDLOW\x10\x02\x12\x0e\n\nSYMBOL_ASK\x10\x03\x12\x12\n\x0eSYMBOL_ASKHIGH\x10\x04\x12\x11\n\rSYMBOL_ASKLOW\x10\x05\x12\x0f\n\x0bSYMBOL_LAST\x10\x06\x12\x13\n\x0fSYMBOL_LASTHIGH\x10\x07\x12\x12\n\x0eSYMBOL_LASTLOW\x10\x08\x12\x16\n\x12SYMBOL_VOLUME_REAL\x10\t\x12\x1a\n\x16SYMBOL_VOLUMEHIGH_REAL\x10\n\x12\x19\n\x15SYMBOL_VOLUMELOW_REAL\x10\x0b\x12\x18\n\x14SYMBOL_OPTION_STRIKE\x10\x0c\x12\x10\n\x0cSYMBOL_POINT\x10\r\x12\x1b\n\x17SYMBOL_TRADE_TICK_VALUE\x10\x0e\x12\"\n\x1eSYMBOL_TRADE_TICK_VALUE_PROFIT\x10\x0f\x12 \n\x1cSYMBOL_TRADE_TICK_VALUE_LOSS\x10\x10\x12\x1a\n\x16SYMBOL_TRADE_TICK_SIZE\x10\x11\x12\x1e\n\x1aSYMBOL_TRADE_CONTRACT_SIZE\x10\x12\x12!\n\x1dSYMBOL_TRADE_ACCRUED_INTEREST\x10\x13\x12\x1b\n\x17SYMBOL_TRADE_FACE_VALUE\x10\x14\x12\x1f\n\x1bSYMBOL_TRADE_LIQUIDITY_RATE\x10\x15\x12\x15\n\x11SYMBOL_VOLUME_MIN\x10\x16\x12\x15\n\x11SYMBOL_VOLUME_MAX\x10\x17\x12\x16\n\x12SYMBOL_VOLUME_STEP\x10\x18\x12\x17\n\x13SYMBOL_VOLUME_LIMIT\x10\x19\x12\x14\n\x10SYMBOL_SWAP_LONG\x10\x1a\x12\x15\n\x11SYMBOL_SWAP_SHORT\x10\x1b\x12\x16\n\x12SYMBOL_SWAP_SUNDAY\x10\x1c\x12\x16\n\x12SYMBOL_SWAP_MONDAY\x10\x1d\x12\x17\n\x13SYMBOL_SWAP_TUESDAY\x10\x1e\x12\x19\n\x15SYMBOL_SWAP_WEDNESDAY\x10\x1f\x12\x18\n\x14SYMBOL_SWAP_THURSDAY\x10 \x12\x16\n\x12SYMBOL_SWAP_FRIDAY\x10!\x12\x18\n\x14SYMBOL_SWAP_SATURDAY\x10\"\x12\x19\n\x15SYMBOL_MARGIN_INITIAL\x10#\x12\x1d\n\x19SYMBOL_MARGIN_MAINTENANCE\x10$\x12\x19\n\x15SYMBOL_SESSION_VOLUME\x10%\x12\x1b\n\x17SYMBOL_SESSION_TURNOVER\x10&\x12\x1b\n\x17SYMBOL_SESSION_INTEREST\x10\'\x12$\n SYMBOL_SESSION_BUY_ORDERS_VOLUME\x10(\x12%\n!SYMBOL_SESSION_SELL_ORDERS_VOLUME\x10)\x12\x17\n\x13SYMBOL_SESSION_OPEN\x10*\x12\x18\n\x14SYMBOL_SESSION_CLOSE\x10+\x12\x15\n\x11SYMBOL_SESSION_AW\x10,\x12#\n\x1fSYMBOL_SESSION_PRICE_SETTLEMENT\x10-\x12\"\n\x1eSYMBOL_SESSION_PRICE_LIMIT_MIN\x10.\x12\"\n\x1eSYMBOL_SESSION_PRICE_LIMIT_MAX\x10/\x12\x18\n\x14SYMBOL_MARGIN_HEDGED\x10\x30\x12\x17\n\x13SYMBOL_PRICE_CHANGE\x10\x31\x12\x1b\n\x17SYMBOL_PRICE_VOLATILITY\x10\x32\x12\x1c\n\x18SYMBOL_PRICE_THEORETICAL\x10\x33\x12\x16\n\x12SYMBOL_PRICE_DELTA\x10\x34\x12\x16\n\x12SYMBOL_PRICE_THETA\x10\x35\x12\x16\n\x12SYMBOL_PRICE_GAMMA\x10\x36\x12\x15\n\x11SYMBOL_PRICE_VEGA\x10\x37\x12\x14\n\x10SYMBOL_PRICE_RHO\x10\x38\x12\x16\n\x12SYMBOL_PRICE_OMEGA\x10\x39\x12\x1c\n\x18SYMBOL_PRICE_SENSITIVITY\x10:\x12\x10\n\x0cSYMBOL_COUNT\x10;*\xa8\x07\n\x19SymbolInfoIntegerProperty\x12\x1d\n\x19SYMBOL_SUBSCRIPTION_DELAY\x10\x00\x12\x11\n\rSYMBOL_SECTOR\x10\x01\x12\x13\n\x0fSYMBOL_INDUSTRY\x10\x02\x12\x11\n\rSYMBOL_CUSTOM\x10\x03\x12\x1b\n\x17SYMBOL_BACKGROUND_COLOR\x10\x04\x12\x15\n\x11SYMBOL_CHART_MODE\x10\x05\x12\x10\n\x0cSYMBOL_EXIST\x10\x06\x12\x11\n\rSYMBOL_SELECT\x10\x07\x12\x12\n\x0eSYMBOL_VISIBLE\x10\x08\x12\x18\n\x14SYMBOL_SESSION_DEALS\x10\t\x12\x1d\n\x19SYMBOL_SESSION_BUY_ORDERS\x10\n\x12\x1e\n\x1aSYMBOL_SESSION_SELL_ORDERS\x10\x0b\x12\x11\n\rSYMBOL_VOLUME\x10\x0c\x12\x15\n\x11SYMBOL_VOLUMEHIGH\x10\r\x12\x14\n\x10SYMBOL_VOLUMELOW\x10\x0e\x12\x0f\n\x0bSYMBOL_TIME\x10\x0f\x12\x13\n\x0fSYMBOL_TIME_MSC\x10\x10\x12\x11\n\rSYMBOL_DIGITS\x10\x11\x12\x17\n\x13SYMBOL_SPREAD_FLOAT\x10\x12\x12\x11\n\rSYMBOL_SPREAD\x10\x13\x12\x1a\n\x16SYMBOL_TICKS_BOOKDEPTH\x10\x14\x12\x1a\n\x16SYMBOL_TRADE_CALC_MODE\x10\x15\x12\x15\n\x11SYMBOL_TRADE_MODE\x10\x16\x12\x15\n\x11SYMBOL_START_TIME\x10\x17\x12\x1a\n\x16SYMBOL_EXPIRATION_TIME\x10\x18\x12\x1c\n\x18SYMBOL_TRADE_STOPS_LEVEL\x10\x19\x12\x1d\n\x19SYMBOL_TRADE_FREEZE_LEVEL\x10\x1a\x12\x18\n\x14SYMBOL_TRADE_EXEMODE\x10\x1b\x12\x14\n\x10SYMBOL_SWAP_MODE\x10\x1c\x12\x1d\n\x19SYMBOL_SWAP_ROLLOVER3DAYS\x10\x1d\x12 \n\x1cSYMBOL_MARGIN_HEDGED_USE_LEG\x10\x1e\x12\x1a\n\x16SYMBOL_EXPIRATION_MODE\x10\x1f\x12\x17\n\x13SYMBOL_FILLING_MODE\x10 \x12\x15\n\x11SYMBOL_ORDER_MODE\x10!\x12\x19\n\x15SYMBOL_ORDER_GTC_MODE\x10\"\x12\x16\n\x12SYMBOL_OPTION_MODE\x10#\x12\x17\n\x13SYMBOL_OPTION_RIGHT\x10$*\xde\x02\n\x18SymbolInfoStringProperty\x12\x10\n\x0cSYMBOL_BASIS\x10\x00\x12\x13\n\x0fSYMBOL_CATEGORY\x10\x01\x12\x12\n\x0eSYMBOL_COUNTRY\x10\x02\x12\x16\n\x12SYMBOL_SECTOR_NAME\x10\x03\x12\x18\n\x14SYMBOL_INDUSTRY_NAME\x10\x04\x12\x18\n\x14SYMBOL_CURRENCY_BASE\x10\x05\x12\x1a\n\x16SYMBOL_CURRENCY_PROFIT\x10\x06\x12\x1a\n\x16SYMBOL_CURRENCY_MARGIN\x10\x07\x12\x0f\n\x0bSYMBOL_BANK\x10\x08\x12\x16\n\x12SYMBOL_DESCRIPTION\x10\t\x12\x13\n\x0fSYMBOL_EXCHANGE\x10\n\x12\x12\n\x0eSYMBOL_FORMULA\x10\x0b\x12\x0f\n\x0bSYMBOL_ISIN\x10\x0c\x12\x0f\n\x0bSYMBOL_PAGE\x10\r\x12\x0f\n\x0bSYMBOL_PATH\x10\x0e*\xfa\x01\n\x0f\x45NUM_ORDER_TYPE\x12\x12\n\x0eORDER_TYPE_BUY\x10\x00\x12\x13\n\x0fORDER_TYPE_SELL\x10\x01\x12\x18\n\x14ORDER_TYPE_BUY_LIMIT\x10\x02\x12\x19\n\x15ORDER_TYPE_SELL_LIMIT\x10\x03\x12\x17\n\x13ORDER_TYPE_BUY_STOP\x10\x04\x12\x18\n\x14ORDER_TYPE_SELL_STOP\x10\x05\x12\x1d\n\x19ORDER_TYPE_BUY_STOP_LIMIT\x10\x06\x12\x1e\n\x1aORDER_TYPE_SELL_STOP_LIMIT\x10\x07\x12\x17\n\x13ORDER_TYPE_CLOSE_BY\x10\x08*g\n\tDayOfWeek\x12\n\n\x06SUNDAY\x10\x00\x12\n\n\x06MONDAY\x10\x01\x12\x0b\n\x07TUESDAY\x10\x02\x12\r\n\tWEDNESDAY\x10\x03\x12\x0c\n\x08THURSDAY\x10\x04\x12\n\n\x06\x46RIDAY\x10\x05\x12\x0c\n\x08SATURDAY\x10\x06*f\n\x08\x42ookType\x12\x12\n\x0e\x42OOK_TYPE_SELL\x10\x00\x12\x11\n\rBOOK_TYPE_BUY\x10\x01\x12\x19\n\x15\x42OOK_TYPE_SELL_MARKET\x10\x02\x12\x18\n\x14\x42OOK_TYPE_BUY_MARKET\x10\x03\x32\xb8\x0e\n\nMarketInfo\x12i\n\x0cSymbolsTotal\x12!.mt5_term_api.SymbolsTotalRequest\x1a\x1f.mt5_term_api.SymbolsTotalReply\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/SymbolsTotal\x12\x65\n\x0bSymbolExist\x12 .mt5_term_api.SymbolExistRequest\x1a\x1e.mt5_term_api.SymbolExistReply\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/SymbolExist\x12\x61\n\nSymbolName\x12\x1f.mt5_term_api.SymbolNameRequest\x1a\x1d.mt5_term_api.SymbolNameReply\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/SymbolName\x12i\n\x0cSymbolSelect\x12!.mt5_term_api.SymbolSelectRequest\x1a\x1f.mt5_term_api.SymbolSelectReply\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/SymbolSelect\x12\x89\x01\n\x14SymbolIsSynchronized\x12).mt5_term_api.SymbolIsSynchronizedRequest\x1a\'.mt5_term_api.SymbolIsSynchronizedReply\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/SymbolIsSynchronized\x12y\n\x10SymbolInfoDouble\x12%.mt5_term_api.SymbolInfoDoubleRequest\x1a#.mt5_term_api.SymbolInfoDoubleReply\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/SymbolInfoDouble\x12}\n\x11SymbolInfoInteger\x12&.mt5_term_api.SymbolInfoIntegerRequest\x1a$.mt5_term_api.SymbolInfoIntegerReply\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/SymbolInfoInteger\x12y\n\x10SymbolInfoString\x12%.mt5_term_api.SymbolInfoStringRequest\x1a#.mt5_term_api.SymbolInfoStringReply\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/SymbolInfoString\x12\x89\x01\n\x14SymbolInfoMarginRate\x12).mt5_term_api.SymbolInfoMarginRateRequest\x1a\'.mt5_term_api.SymbolInfoMarginRateReply\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/SymbolInfoMarginRate\x12x\n\x0eSymbolInfoTick\x12#.mt5_term_api.SymbolInfoTickRequest\x1a(.mt5_term_api.SymbolInfoTickRequestReply\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/SymbolInfoTick\x12\x91\x01\n\x16SymbolInfoSessionQuote\x12+.mt5_term_api.SymbolInfoSessionQuoteRequest\x1a).mt5_term_api.SymbolInfoSessionQuoteReply\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/SymbolInfoSessionQuote\x12\x91\x01\n\x16SymbolInfoSessionTrade\x12+.mt5_term_api.SymbolInfoSessionTradeRequest\x1a).mt5_term_api.SymbolInfoSessionTradeReply\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/SymbolInfoSessionTrade\x12m\n\rMarketBookAdd\x12\".mt5_term_api.MarketBookAddRequest\x1a .mt5_term_api.MarketBookAddReply\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/MarketBookAdd\x12}\n\x11MarketBookRelease\x12&.mt5_term_api.MarketBookReleaseRequest\x1a$.mt5_term_api.MarketBookReleaseReply\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/MarketBookRelease\x12m\n\rMarketBookGet\x12\".mt5_term_api.MarketBookGetRequest\x1a .mt5_term_api.MarketBookGetReply\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/MarketBookGetBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_market_info_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _MARKETINFO.methods_by_name['SymbolsTotal']._options = None
  _MARKETINFO.methods_by_name['SymbolsTotal']._serialized_options = b'\202\323\344\223\002\017\022\r/SymbolsTotal'
  _MARKETINFO.methods_by_name['SymbolExist']._options = None
  _MARKETINFO.methods_by_name['SymbolExist']._serialized_options = b'\202\323\344\223\002\016\022\014/SymbolExist'
  _MARKETINFO.methods_by_name['SymbolName']._options = None
  _MARKETINFO.methods_by_name['SymbolName']._serialized_options = b'\202\323\344\223\002\r\022\013/SymbolName'
  _MARKETINFO.methods_by_name['SymbolSelect']._options = None
  _MARKETINFO.methods_by_name['SymbolSelect']._serialized_options = b'\202\323\344\223\002\017\022\r/SymbolSelect'
  _MARKETINFO.methods_by_name['SymbolIsSynchronized']._options = None
  _MARKETINFO.methods_by_name['SymbolIsSynchronized']._serialized_options = b'\202\323\344\223\002\027\022\025/SymbolIsSynchronized'
  _MARKETINFO.methods_by_name['SymbolInfoDouble']._options = None
  _MARKETINFO.methods_by_name['SymbolInfoDouble']._serialized_options = b'\202\323\344\223\002\023\022\021/SymbolInfoDouble'
  _MARKETINFO.methods_by_name['SymbolInfoInteger']._options = None
  _MARKETINFO.methods_by_name['SymbolInfoInteger']._serialized_options = b'\202\323\344\223\002\024\022\022/SymbolInfoInteger'
  _MARKETINFO.methods_by_name['SymbolInfoString']._options = None
  _MARKETINFO.methods_by_name['SymbolInfoString']._serialized_options = b'\202\323\344\223\002\023\022\021/SymbolInfoString'
  _MARKETINFO.methods_by_name['SymbolInfoMarginRate']._options = None
  _MARKETINFO.methods_by_name['SymbolInfoMarginRate']._serialized_options = b'\202\323\344\223\002\027\022\025/SymbolInfoMarginRate'
  _MARKETINFO.methods_by_name['SymbolInfoTick']._options = None
  _MARKETINFO.methods_by_name['SymbolInfoTick']._serialized_options = b'\202\323\344\223\002\021\022\017/SymbolInfoTick'
  _MARKETINFO.methods_by_name['SymbolInfoSessionQuote']._options = None
  _MARKETINFO.methods_by_name['SymbolInfoSessionQuote']._serialized_options = b'\202\323\344\223\002\031\022\027/SymbolInfoSessionQuote'
  _MARKETINFO.methods_by_name['SymbolInfoSessionTrade']._options = None
  _MARKETINFO.methods_by_name['SymbolInfoSessionTrade']._serialized_options = b'\202\323\344\223\002\031\022\027/SymbolInfoSessionTrade'
  _MARKETINFO.methods_by_name['MarketBookAdd']._options = None
  _MARKETINFO.methods_by_name['MarketBookAdd']._serialized_options = b'\202\323\344\223\002\020\022\016/MarketBookAdd'
  _MARKETINFO.methods_by_name['MarketBookRelease']._options = None
  _MARKETINFO.methods_by_name['MarketBookRelease']._serialized_options = b'\202\323\344\223\002\024\022\022/MarketBookRelease'
  _MARKETINFO.methods_by_name['MarketBookGet']._options = None
  _MARKETINFO.methods_by_name['MarketBookGet']._serialized_options = b'\202\323\344\223\002\020\022\016/MarketBookGet'
  _SYMBOLINFODOUBLEPROPERTY._serialized_start=4123
  _SYMBOLINFODOUBLEPROPERTY._serialized_end=5714
  _SYMBOLINFOINTEGERPROPERTY._serialized_start=5717
  _SYMBOLINFOINTEGERPROPERTY._serialized_end=6653
  _SYMBOLINFOSTRINGPROPERTY._serialized_start=6656
  _SYMBOLINFOSTRINGPROPERTY._serialized_end=7006
  _ENUM_ORDER_TYPE._serialized_start=7009
  _ENUM_ORDER_TYPE._serialized_end=7259
  _DAYOFWEEK._serialized_start=7261
  _DAYOFWEEK._serialized_end=7364
  _BOOKTYPE._serialized_start=7366
  _BOOKTYPE._serialized_end=7468
  _SYMBOLSTOTALREQUEST._serialized_start=133
  _SYMBOLSTOTALREQUEST._serialized_end=168
  _SYMBOLSTOTALREPLY._serialized_start=170
  _SYMBOLSTOTALREPLY._serialized_end=287
  _SYMBOLSTOTALDATA._serialized_start=289
  _SYMBOLSTOTALDATA._serialized_end=322
  _SYMBOLEXISTREQUEST._serialized_start=324
  _SYMBOLEXISTREQUEST._serialized_end=358
  _SYMBOLEXISTREPLY._serialized_start=360
  _SYMBOLEXISTREPLY._serialized_end=475
  _SYMBOLEXISTDATA._serialized_start=477
  _SYMBOLEXISTDATA._serialized_end=529
  _SYMBOLNAMEREQUEST._serialized_start=531
  _SYMBOLNAMEREQUEST._serialized_end=583
  _SYMBOLNAMEREPLY._serialized_start=585
  _SYMBOLNAMEREPLY._serialized_end=698
  _SYMBOLNAMEDATA._serialized_start=700
  _SYMBOLNAMEDATA._serialized_end=730
  _SYMBOLSELECTREQUEST._serialized_start=732
  _SYMBOLSELECTREQUEST._serialized_end=785
  _SYMBOLSELECTREPLY._serialized_start=787
  _SYMBOLSELECTREPLY._serialized_end=904
  _SYMBOLSELECTDATA._serialized_start=906
  _SYMBOLSELECTDATA._serialized_end=941
  _SYMBOLISSYNCHRONIZEDREQUEST._serialized_start=943
  _SYMBOLISSYNCHRONIZEDREQUEST._serialized_end=988
  _SYMBOLISSYNCHRONIZEDREPLY._serialized_start=991
  _SYMBOLISSYNCHRONIZEDREPLY._serialized_end=1124
  _SYMBOLISSYNCHRONIZEDDATA._serialized_start=1126
  _SYMBOLISSYNCHRONIZEDDATA._serialized_end=1174
  _SYMBOLINFODOUBLEREQUEST._serialized_start=1176
  _SYMBOLINFODOUBLEREQUEST._serialized_end=1271
  _SYMBOLINFODOUBLEREPLY._serialized_start=1273
  _SYMBOLINFODOUBLEREPLY._serialized_end=1398
  _SYMBOLINFODOUBLEDATA._serialized_start=1400
  _SYMBOLINFODOUBLEDATA._serialized_end=1437
  _SYMBOLINFOINTEGERREQUEST._serialized_start=1439
  _SYMBOLINFOINTEGERREQUEST._serialized_end=1536
  _SYMBOLINFOINTEGERREPLY._serialized_start=1538
  _SYMBOLINFOINTEGERREPLY._serialized_end=1665
  _SYMBOLINFOINTEGERDATA._serialized_start=1667
  _SYMBOLINFOINTEGERDATA._serialized_end=1705
  _SYMBOLINFOSTRINGREQUEST._serialized_start=1707
  _SYMBOLINFOSTRINGREQUEST._serialized_end=1802
  _SYMBOLINFOSTRINGREPLY._serialized_start=1804
  _SYMBOLINFOSTRINGREPLY._serialized_end=1929
  _SYMBOLINFOSTRINGDATA._serialized_start=1931
  _SYMBOLINFOSTRINGDATA._serialized_end=1968
  _SYMBOLINFOMARGINRATEREQUEST._serialized_start=1970
  _SYMBOLINFOMARGINRATEREQUEST._serialized_end=2066
  _SYMBOLINFOMARGINRATEREPLY._serialized_start=2069
  _SYMBOLINFOMARGINRATEREPLY._serialized_end=2202
  _SYMBOLINFOMARGINRATEDATA._serialized_start=2204
  _SYMBOLINFOMARGINRATEDATA._serialized_end=2292
  _SYMBOLINFOTICKREQUEST._serialized_start=2294
  _SYMBOLINFOTICKREQUEST._serialized_end=2333
  _SYMBOLINFOTICKREQUESTREPLY._serialized_start=2335
  _SYMBOLINFOTICKREQUESTREPLY._serialized_end=2456
  _MRPCMQLTICK._serialized_start=2459
  _MRPCMQLTICK._serialized_end=2596
  _SYMBOLINFOSESSIONQUOTEREQUEST._serialized_start=2598
  _SYMBOLINFOSESSIONQUOTEREQUEST._serialized_end=2714
  _SYMBOLINFOSESSIONQUOTEREPLY._serialized_start=2717
  _SYMBOLINFOSESSIONQUOTEREPLY._serialized_end=2854
  _SYMBOLINFOSESSIONQUOTEDATA._serialized_start=2856
  _SYMBOLINFOSESSIONQUOTEDATA._serialized_end=2966
  _SYMBOLINFOSESSIONTRADEREQUEST._serialized_start=2968
  _SYMBOLINFOSESSIONTRADEREQUEST._serialized_end=3084
  _SYMBOLINFOSESSIONTRADEREPLY._serialized_start=3087
  _SYMBOLINFOSESSIONTRADEREPLY._serialized_end=3224
  _SYMBOLINFOSESSIONTRADEDATA._serialized_start=3226
  _SYMBOLINFOSESSIONTRADEDATA._serialized_end=3336
  _MARKETBOOKADDREQUEST._serialized_start=3338
  _MARKETBOOKADDREQUEST._serialized_end=3376
  _MARKETBOOKADDREPLY._serialized_start=3378
  _MARKETBOOKADDREPLY._serialized_end=3497
  _MARKETBOOKADDDATA._serialized_start=3499
  _MARKETBOOKADDDATA._serialized_end=3547
  _MARKETBOOKRELEASEREQUEST._serialized_start=3549
  _MARKETBOOKRELEASEREQUEST._serialized_end=3591
  _MARKETBOOKRELEASEREPLY._serialized_start=3593
  _MARKETBOOKRELEASEREPLY._serialized_end=3720
  _MARKETBOOKRELEASEDATA._serialized_start=3722
  _MARKETBOOKRELEASEDATA._serialized_end=3774
  _MARKETBOOKGETREQUEST._serialized_start=3776
  _MARKETBOOKGETREQUEST._serialized_end=3814
  _MARKETBOOKGETREPLY._serialized_start=3816
  _MARKETBOOKGETREPLY._serialized_end=3935
  _MARKETBOOKGETDATA._serialized_start=3937
  _MARKETBOOKGETDATA._serialized_end=4011
  _MRPCMQLBOOKINFO._serialized_start=4013
  _MRPCMQLBOOKINFO._serialized_end=4120
  _MARKETINFO._serialized_start=7471
  _MARKETINFO._serialized_end=9319
# @@protoc_insertion_point(module_scope)
