# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-internal-charts.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"mt5-term-api-internal-charts.proto\x12\x0cmt5_term_api\",\n\x18SaveChartTemplateRequest\x12\x10\n\x08\x63hart_id\x18\x01 \x01(\x03\"+\n\x16SaveChartTemplateReply\x12\x11\n\tfile_name\x18\x01 \x01(\t\"\xc5\x01\n\x16OpenChartWithEaRequest\x12\x13\n\x0bsymbol_name\x18\x01 \x01(\t\x12\x14\n\x0c\x65\x61_file_name\x18\x02 \x01(\t\x12\x41\n\x0c\x63hart_period\x18\x03 \x01(\x0e\x32+.mt5_term_api.EnumOpenChartWithEaChatPeriod\x12=\n\rea_parameters\x18\x04 \x03(\x0b\x32&.mt5_term_api.OpenChartWithEaParameter\"\xf1\x02\n\x18OpenChartWithEaParameter\x12\r\n\x05index\x18\x01 \x01(\x05\x12<\n\x04type\x18\x02 \x01(\x0e\x32..mt5_term_api.EnumOpenChartWithEaParemeterType\x12\x1c\n\x0fint_param_value\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x1d\n\x10long_param_value\x18\x04 \x01(\x03H\x01\x88\x01\x01\x12\x1d\n\x10\x62ool_param_value\x18\x05 \x01(\x08H\x02\x88\x01\x01\x12\x1f\n\x12string_param_value\x18\x06 \x01(\tH\x03\x88\x01\x01\x12\x1f\n\x12\x64ouble_param_value\x18\x07 \x01(\x01H\x04\x88\x01\x01\x42\x12\n\x10_int_param_valueB\x13\n\x11_long_param_valueB\x13\n\x11_bool_param_valueB\x15\n\x13_string_param_valueB\x15\n\x13_double_param_value\"(\n\x14OpenChartWithEaReply\x12\x10\n\x08\x63hart_id\x18\x01 \x01(\x03\"\xc6\x01\n\x19OpenChartForSymbolRequest\x12\x13\n\x0bsymbol_name\x18\x01 \x01(\t\x12\x32\n\x0b\x65xpert_mode\x18\x02 \x01(\x0e\x32\x1d.mt5_term_api.ChartExpertMode\x12\x19\n\x0ctimer_period\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x1e\n\x11ignore_empty_data\x18\x04 \x01(\x08H\x01\x88\x01\x01\x42\x0f\n\r_timer_periodB\x14\n\x12_ignore_empty_data\"/\n\x17OpenChartForSymbolReply\x12\x14\n\x0cmql_chart_id\x18\x01 \x01(\x03\"2\n\x1a\x43loseChartForSymbolRequest\x12\x14\n\x0cmql_chart_id\x18\x01 \x01(\x03\"\x1a\n\x18\x43loseChartForSymbolReply*\x84\x01\n EnumOpenChartWithEaParemeterType\x12\x10\n\x0c\x45\x41_PARAM_INT\x10\x00\x12\x11\n\rEA_PARAM_LONG\x10\x01\x12\x11\n\rEA_PARAM_BOOL\x10\x02\x12\x13\n\x0f\x45\x41_PARAM_STRING\x10\x03\x12\x13\n\x0f\x45\x41_PARAM_DOUBLE\x10\x04*\xbb\x04\n\x1d\x45numOpenChartWithEaChatPeriod\x12\x1b\n\x17\x45\x41_CHART_PERIOD_CURRENT\x10\x00\x12\x16\n\x12\x45\x41_CHART_PERIOD_M1\x10\x01\x12\x16\n\x12\x45\x41_CHART_PERIOD_M2\x10\x02\x12\x16\n\x12\x45\x41_CHART_PERIOD_M3\x10\x03\x12\x16\n\x12\x45\x41_CHART_PERIOD_M4\x10\x04\x12\x16\n\x12\x45\x41_CHART_PERIOD_M5\x10\x05\x12\x16\n\x12\x45\x41_CHART_PERIOD_M6\x10\x06\x12\x17\n\x13\x45\x41_CHART_PERIOD_M10\x10\x07\x12\x17\n\x13\x45\x41_CHART_PERIOD_M12\x10\x08\x12\x17\n\x13\x45\x41_CHART_PERIOD_M15\x10\t\x12\x17\n\x13\x45\x41_CHART_PERIOD_M20\x10\n\x12\x17\n\x13\x45\x41_CHART_PERIOD_M30\x10\x0b\x12\x16\n\x12\x45\x41_CHART_PERIOD_H1\x10\x0c\x12\x16\n\x12\x45\x41_CHART_PERIOD_H2\x10\r\x12\x16\n\x12\x45\x41_CHART_PERIOD_H3\x10\x0e\x12\x16\n\x12\x45\x41_CHART_PERIOD_H4\x10\x0f\x12\x16\n\x12\x45\x41_CHART_PERIOD_H6\x10\x10\x12\x16\n\x12\x45\x41_CHART_PERIOD_H8\x10\x11\x12\x17\n\x13\x45\x41_CHART_PERIOD_H12\x10\x12\x12\x16\n\x12\x45\x41_CHART_PERIOD_D1\x10\x13\x12\x16\n\x12\x45\x41_CHART_PERIOD_W1\x10\x14\x12\x17\n\x13\x45\x41_CHART_PERIOD_MN1\x10\x15*y\n\x0f\x43hartExpertMode\x12\x0b\n\x07ON_TICK\x10\x00\x12\x0c\n\x08ON_TRADE\x10\x01\x12\x13\n\x0fON_ORDER_PROFIT\x10\x02\x12\x1c\n\x18ON_OPENED_ORDERS_TICKETS\x10\x03\x12\x18\n\x14ON_TRADE_TRANSACTION\x10\x04\x32\x9f\x03\n\x0eInternalCharts\x12\x64\n\x12OpenChartForSymbol\x12\'.mt5_term_api.OpenChartForSymbolRequest\x1a%.mt5_term_api.OpenChartForSymbolReply\x12g\n\x13\x43loseChartForSymbol\x12(.mt5_term_api.CloseChartForSymbolRequest\x1a&.mt5_term_api.CloseChartForSymbolReply\x12[\n\x0fOpenChartWithEa\x12$.mt5_term_api.OpenChartWithEaRequest\x1a\".mt5_term_api.OpenChartWithEaReply\x12\x61\n\x11SaveChartTemplate\x12&.mt5_term_api.SaveChartTemplateRequest\x1a$.mt5_term_api.SaveChartTemplateReplyBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_internal_charts_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _ENUMOPENCHARTWITHEAPAREMETERTYPE._serialized_start=1088
  _ENUMOPENCHARTWITHEAPAREMETERTYPE._serialized_end=1220
  _ENUMOPENCHARTWITHEACHATPERIOD._serialized_start=1223
  _ENUMOPENCHARTWITHEACHATPERIOD._serialized_end=1794
  _CHARTEXPERTMODE._serialized_start=1796
  _CHARTEXPERTMODE._serialized_end=1917
  _SAVECHARTTEMPLATEREQUEST._serialized_start=52
  _SAVECHARTTEMPLATEREQUEST._serialized_end=96
  _SAVECHARTTEMPLATEREPLY._serialized_start=98
  _SAVECHARTTEMPLATEREPLY._serialized_end=141
  _OPENCHARTWITHEAREQUEST._serialized_start=144
  _OPENCHARTWITHEAREQUEST._serialized_end=341
  _OPENCHARTWITHEAPARAMETER._serialized_start=344
  _OPENCHARTWITHEAPARAMETER._serialized_end=713
  _OPENCHARTWITHEAREPLY._serialized_start=715
  _OPENCHARTWITHEAREPLY._serialized_end=755
  _OPENCHARTFORSYMBOLREQUEST._serialized_start=758
  _OPENCHARTFORSYMBOLREQUEST._serialized_end=956
  _OPENCHARTFORSYMBOLREPLY._serialized_start=958
  _OPENCHARTFORSYMBOLREPLY._serialized_end=1005
  _CLOSECHARTFORSYMBOLREQUEST._serialized_start=1007
  _CLOSECHARTFORSYMBOLREQUEST._serialized_end=1057
  _CLOSECHARTFORSYMBOLREPLY._serialized_start=1059
  _CLOSECHARTFORSYMBOLREPLY._serialized_end=1085
  _INTERNALCHARTS._serialized_start=1920
  _INTERNALCHARTS._serialized_end=2335
# @@protoc_insertion_point(module_scope)
